@@ -112,14 +112,6 @@ clear(String<TValue, CStyle> & me);
 struct CStyle_;
 typedef Tag<CStyle_> CStyle;
 
-#ifdef PLATFORM_WINDOWS_VS
-#pragma warning( push )
-// Disable warning C4521 locally (multiple copy constructors).
-#pragma warning( disable: 4521 )
-// Disable warning C4522 locally (multiple assignment operators).
-#pragma warning( disable: 4522 )
-#endif  // PLATFORM_WINDOWS_VS
-
 template <typename TValue>
 class String <TValue, CStyle >
 {
@@ -220,11 +212,6 @@ public:
 template <typename TValue>
 TValue String<TValue, CStyle >::EMPTY_STRING = TValue();
 
-#ifdef PLATFORM_WINDOWS_VS
-// Reset warning state to previous one for C4521, C4522.
-#pragma warning( pop )
-#endif  // PLATFORM_WINDOWS_VS
-
 // ============================================================================
 // Metafunctions
 // ============================================================================
