@@ -503,8 +503,9 @@ class HtmlWriter(object):
     def generateSearchIndex(self, doc):
         """Generate the search index."""
         js = ['window.searchData = [']
+        js_module = ['window.searchDataModule = [']
         for entry in doc.top_level_entries.itervalues():
-            akas, subentries = '', ''
+            akas, subentries, headerfile = '', '', ''
             if hasattr(entry, 'akas'):
                 akas = ','.join(entry.akas)
             if hasattr(entry, 'subentries'):
@@ -514,13 +515,28 @@ class HtmlWriter(object):
                         sID = s.title
                         title = proc_doc.splitSecondLevelEntry(s.title)[1]
                         subentries.append({'type': s.kind, 'name': s.name, 'title': title, 'id': sID})
+            if hasattr(entry, 'headerfiles') and len(entry.headerfiles) > 0 :
+                headerfile = entry.headerfiles[0]
+                headerfile = headerfile[headerfile.find("/")+1:-3]
+
+            if entry in self.doc.doc_processor.topLevelEntry_filenames:
+                delimiter = "/include/seqan/"
+                srcfile = self.doc.doc_processor.topLevelEntry_filenames[entry]
+                srcfile = srcfile[srcfile.find(delimiter)+len(delimiter):]
+            else :
+                srcfile = ""
+
             js.append('  {title:%s,name:%s,text:%s,akas:%s,subentries:%s,loc:%s,langEntity:%s},' %
                       (repr(entry.title), repr(entry.name), repr(""), repr(akas), repr(subentries),
-                       repr(self.path_converter.convert(entry.name)[0]),
-                       repr(entry.kind)))
+                       repr(self.path_converter.convert(entry.name)[0]), repr(entry.kind)))
+            js_module.append('  {definedIn:%s,srcfile:%s},' % (repr(headerfile), repr(srcfile)))
         js.append('];')
+        js_module.append('];')
+
         with open(os.path.join(self.out_dirs['js'], 'search.data.js'), 'wb') as f:
             f.write('\n'.join(js))
+        with open(os.path.join(self.out_dirs['js'], 'search.data.module.js'), 'wb') as f:
+            f.write('\n'.join(js_module))
 
     def generateLinkData(self, doc):
         """Generate the Data for top level entry links."""
